# pygrisb
Python library for preprocessing, managing and postprocessing 
the (DFT+) Gutzwiller-RISB calculations. 
It is used by [CyGutz](https://github.com/yaoyongxin/CyGutz)
and [comsuite](https://www.bnl.gov/comscope/software/comsuite.php).
